/****************************************************************
Project : PPE SERRE
Version : 1
// --------------------------------------------------------------
Fichier source : Lum.c
Date de  cration : 20/12/2010
Mise  jour le :
// --------------------------------------------------------------
Author  : Philippe Mariano
Company : Lyce Pierre Emile Martin 18000 BOURGES
// --------------------------------------------------------------
Comments: Lecture de la luminosit et affichage sur un LCD
// --------------------------------------------------------------
Cross compilateur: CVAVR 2.04.5b
// --------------------------------------------------------------
Chip type           : ATmega8535
Program type        : Application
Clock frequency     : 8,000000 MHz
Memory model        : Small
External SRAM size  : 0
Data Stack size     : 512
****************************************************************/

#include <mega8535.h>
 #include <stdio.h>      // contient la fonction sprintf()
#include <delay.h>    	// contient la fonction delay_ms()


// Seuils de luminosit
// ---------------------------------------------------------------------------
#define LumJour     230
#define LumNuit     50
// ---------------------------------------------------------------------------

// Alphanumeric LCD Module functions
#asm
   .equ __lcd_port=0x15 ;PORTC
#endasm
#include <lcd.h>

#define ADC_VREF_TYPE 0x20

// Read the 8 most significant bits
// of the AD conversion result
unsigned char read_adc(unsigned char adc_input)
{
ADMUX=adc_input | (ADC_VREF_TYPE & 0xff);
// Delay needed for the stabilization of the ADC input voltage
delay_us(10);
// Start the AD conversion
ADCSRA|=0x40;
// Wait for the AD conversion to complete
while ((ADCSRA & 0x10)==0);
ADCSRA|=0x10;
return ADCH;
}

// Declare your global variables here

void main(void)
{
// Declare your local variables here
// -------------------------------------------------------------------------------------
// Type 		Nom 		            Commentaires
// -------------------------------------------------------------------------------------
unsigned char Lum = 0;			        // Image de la luminosit
char display_buffer[17];	    // Buffer pour la premire ligne de l'afficheur
// --------------------------------------------------------------------------------------

// ADC initialization
// ADC Clock frequency: 62,500 kHz
// ADC Voltage Reference: AREF pin
// ADC High Speed Mode: Off
// ADC Auto Trigger Source: ADC Stopped
// Only the 8 most significant bits of
// the AD conversion result are used
ADMUX=ADC_VREF_TYPE & 0xff;
ADCSRA=0x87;
SFIOR&=0xEF;

// LCD module initialization
lcd_init(16);

lcd_clear();
sprintf(display_buffer,"PPE SERRE (Lum) ");
lcd_puts(display_buffer);
delay_ms(5000);             // Attente de 5s avant la premire mesure

while (1)
      {
// -----------------------------------------------------------------------------------------
// ----------------------------- Lecture de la luminosit ----------------------------------
	    Lum = read_adc(1);
// -----------------------------------------------------------------------------------------
// --------------------------------------- Traitement --------------------------------------
	    if ((Lum > LumJour) || (Lum == LumJour))
 	 	            sprintf(display_buffer,"Jour");
 		else if ((Lum < LumNuit)||(Lum == LumNuit))
 		            sprintf(display_buffer,"Nuit");
// ---------------------------------------- Affichage --------------------------------------
	    lcd_clear();
 	 	lcd_puts(display_buffer);
        delay_ms(5000);
      };
}
// -----------------------------------------------------------------------------------------